% Beam MATLAB Code with Member Loads
% Units: Kilonewtons (kN) and Millimeters (mm)

clc     %Clear the window
clear   %Clear the memory

% This general format works well for most engineering problems
format short g

% Define the number of element dofs (always 4 for the beam element)
NEdof=4;

% Define the number of structural dofs
NSdof=3;

% Initialize {Pf} and [S]
Pf=zeros(NSdof,1);
S=zeros(NSdof,NSdof);

E=20;

P=[0;0;6*1000] % The semicolon is a separator between rows in the vector

% Define the code numbers
CodeNum=[
4 5 6 1
6 1 2 3] % Here we write out each row explicitly

% Define geometry and loading for each member, create the member stiffness and fixed-end-force vectors
% and then assemble {Pf} and [S]. Note that no units are shown, you just need to
% be consistent.

MemNum=1;
Qf1=zeros(NEdof,1);
Qfs1=zeros(NEdof,1);
I=(300*400^3)/12;
L=4*1000;
                             % Fixed End Forces/Moments   
w=3/1000;                    % Note: (+) Uniform LOAD assumed down
FSb=w*L/2;     
FMb=w*(L^2)/12;              % (+) reactions: force UP, (+) moment CCW
FSe=w*L/2;
FMe=-w*(L^2)/12;
Qf1=[FSb;FMb;FSe;FMe]

[k1]=Create_K(E,I,L)

ufs1=[0; 0; -0.5; 0];       % Support displacement
Qfs1=k1*ufs1  

[S,Pf]=Assemble_S_Pf(S,k1,Pf,Qf1,Qfs1,MemNum,NEdof,NSdof,CodeNum);


MemNum=2;
Qf2=zeros(NEdof,1);
Qfs2=zeros(NEdof,1);
I=(300*400^3)/12;
L=2*1000;
                            % Fixed End Forces/Moments
W=24;                       % Note: (+) Concentrated FORCE assumed down
FSb=W/2;          
FMb=W*L/8;                  % (+) reactions: force UP, (+) moment CCW
FSe=W/2;
FMe=-W*L/8;
Qf2=[FSb;FMb;FSe;FMe]

[k2]=Create_K(E,I,L)

ufs2=[-0.5; 0; 0; 0];       % Support displacement
Qfs2=k2*ufs2  

[S,Pf]=Assemble_S_Pf(S,k2,Pf,Qf2,Qfs2,MemNum,NEdof,NSdof,CodeNum);


%***************** SOLVE *****************

Pf

S

% Solve for displacements (note the use of the backslash operator instead
% of the inv command. We could have used d=inv(S)*(P-Pf), or even
% d=S^-1*(P-Pf), but the backslash approach is much more efficient.)
d=S\(P-Pf)


%************** POST-PROCESS *************

% Use compatibility to create the {u} vectors for each element
u1=[0; 0; -0.5; d(1)];
u2=[-0.5; d(1); d(2); d(3)];


% Calculate the member end forces
Q1=Qf1+k1*u1
Q2=Qf2+k2*u2

% Calculate the support reactions
R4=Q1(1)
R5=Q1(2)
R6=Q1(3)+Q2(1)    % Index(i) selects corresponding member end force 1,2,3,4

